@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -32,7 +32,7 @@
 //! \return new imagefile_dossier object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 PyObject *
-PyMobius_Imagefile_Imagefile_Dossier_from_cpp (mobius::imagefile::imagefile_dossier obj)
+pymobius_imagefile_imagefile_dossier_to_pyobject (mobius::imagefile::imagefile_dossier obj)
 {
   PyObject *ret = _PyObject_New (&imagefile_imagefile_dossier_t);
 
@@ -54,11 +54,11 @@ tp_getter_segments (imagefile_imagefile_dossier_o *self)
 
   try
     {
-      ret = PyLong_FromUnsignedLongLong (self->obj->get_segments ());
+      ret = mobius::py::pylong_from_std_uint64_t (self->obj->get_segments ());
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -76,11 +76,11 @@ tp_getter_segment_size (imagefile_imagefile_dossier_o *self)
 
   try
     {
-      ret = PyLong_FromUnsignedLongLong (self->obj->get_segment_size ());
+      ret = mobius::py::pylong_from_std_uint64_t (self->obj->get_segment_size ());
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -102,7 +102,7 @@ tp_getter_drive_vendor (imagefile_imagefile_dossier_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -124,7 +124,7 @@ tp_getter_drive_model (imagefile_imagefile_dossier_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -146,7 +146,7 @@ tp_getter_drive_serial_number (imagefile_imagefile_dossier_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -168,7 +168,7 @@ tp_getter_acquisition_user (imagefile_imagefile_dossier_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -190,7 +190,7 @@ tp_getter_acquisition_time (imagefile_imagefile_dossier_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -212,7 +212,7 @@ tp_getter_acquisition_tool (imagefile_imagefile_dossier_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
@@ -234,7 +234,7 @@ tp_getter_acquisition_platform (imagefile_imagefile_dossier_o *self)
     }
   catch (const std::exception& e)
     {
-      PyErr_SetString (PyExc_Exception, e.what ());
+      mobius::py::set_runtime_error (e.what ());
     }
 
   return ret;
