@@ -1,6 +1,6 @@
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # Mobius Forensic Toolkit
-# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021 Eduardo Aguiar
+# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -15,9 +15,9 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-import pymobius.xml
 import pymobius.registry
 import pymobius.registry.main
+import pymobius.vfs
 import model
 import ares
 import emuletorrent
@@ -132,11 +132,15 @@ class Ant (object):
   # @brief retrieve data
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   def __retrieve_data (self):
-    pymobius.LOG ('pymobius.p2p.__retrieve_data (1)')
+    vfs = pymobius.vfs.get_item_vfs (self.__item)
+    if not vfs:
+      raise Exception ('Datasource is not available')
+
+    mobius.core.logf ('DBG pymobius.p2p.__retrieve_data (1)')
     self.__model = model.model (self.__item)
 
     # Clear p2p ignored kff, if any
-    pymobius.LOG ('pymobius.p2p.__retrieve_data (2)')
+    mobius.core.logf ('DBG pymobius.p2p.__retrieve_data (2)')
     case = self.__item.case
     path = case.get_path (os.path.join ('hashset', '%04d-p2p.ignore' % self.__item.uid))
 
@@ -144,27 +148,27 @@ class Ant (object):
       os.remove (path)
 
     # Retrieve activity data
-    pymobius.LOG ('pymobius.p2p.__retrieve_data (3.1)')
+    mobius.core.logf ('DBG pymobius.p2p.__retrieve_data (3.1)')
     pymobius.p2p.ares.retrieve (self.__model)
-    pymobius.LOG ('pymobius.p2p.__retrieve_data (3.2)')
+    mobius.core.logf ('DBG pymobius.p2p.__retrieve_data (3.2)')
     pymobius.p2p.emule.retrieve (self.__model)
-    pymobius.LOG ('pymobius.p2p.__retrieve_data (3.3)')
+    mobius.core.logf ('DBG pymobius.p2p.__retrieve_data (3.3)')
     pymobius.p2p.emuletorrent.retrieve (self.__model)
-    pymobius.LOG ('pymobius.p2p.__retrieve_data (3.4)')
+    mobius.core.logf ('DBG pymobius.p2p.__retrieve_data (3.4)')
     pymobius.p2p.shareaza.retrieve (self.__model)
-    pymobius.LOG ('pymobius.p2p.__retrieve_data (3.5)')
+    mobius.core.logf ('DBG pymobius.p2p.__retrieve_data (3.5)')
 
     # Normalize data
-    pymobius.LOG ('pymobius.p2p.__retrieve_data (4)')
+    mobius.core.logf ('DBG pymobius.p2p.__retrieve_data (4)')
     self.__calculate_totals ()
     self.__model.accounts = unique ((a, a.network, a.guid) for a in self.__model.accounts)
 
     # Save data model
-    pymobius.LOG ('pymobius.p2p.__retrieve_data (5)')
+    mobius.core.logf ('DBG pymobius.p2p.__retrieve_data (5)')
     path = self.__item.create_data_path ('p2p.json')
     self.__model.save (path)
     self.__is_data_available = True
-    pymobius.LOG ('pymobius.p2p.__retrieve_data (6)')
+    mobius.core.logf ('DBG pymobius.p2p.__retrieve_data (6)')
 
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   # @brief Calculate totals by application
