@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -96,6 +96,9 @@ get_type_from_url (const std::string& url)
   if (extension == "001")
     type = "split";
 
+  else if (extension == "E01")
+    type = "ewf";
+
   else
     type = "raw";
 
@@ -210,7 +213,7 @@ main (int argc, char **argv)
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   // check if input imagefile is available
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  auto image_in = mobius::imagefile::new_imagefile_from_url (input_url, input_type_arg);
+  auto image_in = mobius::imagefile::new_imagefile_by_url (input_url, input_type_arg);
 
   if (!image_in.is_available ())
     {
@@ -223,12 +226,13 @@ main (int argc, char **argv)
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   // create output imagefile
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-  auto image_out = mobius::imagefile::new_imagefile_from_url (output_url, output_type_arg);
+  auto image_out = mobius::imagefile::new_imagefile_by_url (output_url, output_type_arg);
 
   if (image_out.get_type () == "ewf")
     {
       mobius::imagefile::imagefile_ewf image (image_out);
       image.set_segment_size (get_size (segment_size_arg));
+      image.set_compression_level (1);
     }
 
   else if (image_out.get_type () == "split")
@@ -242,14 +246,14 @@ main (int argc, char **argv)
   // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   auto reader = image_in.new_reader ();
   auto writer = image_out.new_writer ();
-  constexpr decltype (reader)::size_type BLOCK_SIZE = 65536;
+  auto block_size = reader.get_block_size ();
 
   std::cout << std::endl;
   std::cout << "About to copy " << reader.get_size () << " bytes" << std::endl;
   std::cout << "  from " << input_url << std::endl;
   std::cout << "  to " << output_url << std::endl;
 
-  auto data = reader.read (BLOCK_SIZE);
+  auto data = reader.read (block_size);
   auto size = reader.get_size ();
   decltype (size) copied = 0;
 
@@ -258,6 +262,8 @@ main (int argc, char **argv)
       writer.write (data);
       copied += data.size ();
       printf ("Copied %lu bytes\r", copied);
-      data = reader.read (BLOCK_SIZE);
+      data = reader.read (block_size);
     }
+    
+  std::cout << std::endl;
 }
